@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 # All Rights Reserved.
 #
@@ -60,13 +59,7 @@ PHASES = ['pre-configure',
 
 def timeout():
     p = psutil.Process()
-    try:
-        # psutils version >= 2
-        children = list(p.children(recursive=True))
-    except AttributeError:
-        children = list(p.get_children(recursive=True))
-
-    for child in children:
+    for child in p.children(recursive=True):
         child.kill()
 
 
@@ -121,8 +114,8 @@ def main(argv=sys.argv):
     lock = open(options.lockfile, 'a')
     try:
         fcntl.flock(lock, fcntl.LOCK_EX | fcntl.LOCK_NB)
-    except IOError as e:
-        log.error('Could not lock %s. %s' % (options.lockfile, e))
+    except OSError as e:
+        log.error('Could not lock {}. {}'.format(options.lockfile, e))
         return e.errno
 
     lock.truncate(0)
@@ -151,7 +144,7 @@ def main(argv=sys.argv):
                 sys.stderr.flush()
                 log.info('Completed phase %s' % phase)
             except subprocess.CalledProcessError as e:
-                log.error("during %s phase. [%s]\n" % (phase, e))
+                log.error("during {} phase. [{}]\n".format(phase, e))
                 error_dir = os.path.join(BASE_DIR, 'error.d')
                 if os.path.exists(error_dir):
                     log.info('Calling error handlers.')
@@ -165,7 +158,3 @@ def main(argv=sys.argv):
             log.debug('No dir for phase %s' % phase)
 
     return exit(lock)
-
-
-if __name__ == '__main__':
-    sys.exit(main(sys.argv))
